@@ -260,14 +260,15 @@ def slice_vcf(vcf_bgzipped_file, chrm, start, stop):
 
 
 def parse_info_field(info_field):
-    
+
     info_dict = {}
     for item in info_field.split(';'):
-        pair = item.split("=") 
+        pair = item.split("=")
         if len(pair) == 2:
-            info_dict[pair[0]] = pair[1] # this could be improved on
+            info_dict[pair[0]] = pair[1]   # this could be improved on
     return info_dict
 
+
 def parse_vcf_line(pos, vcf_line_dict):
     """Read in VCF line and convert it to an OrderedDict"""
 
@@ -484,7 +485,7 @@ def calc_multilocus_f_statistics(Hs_est_dict, Ht_est_dict):
             Gst_est = fstats.multilocus_Gst_est(Ht_est_list_no_NaN, Hs_est_list_no_NaN)
             G_prime_st_est = fstats.multilocus_G_prime_st_est(Ht_est_list_no_NaN, Hs_est_list_no_NaN, n)
             G_double_prime_st_est = fstats.multilocus_G_double_prime_st_est(Ht_est_list_no_NaN, Hs_est_list_no_NaN, n)
-            
+
             # NOTE that the Dest calculation handles NaN's better and
             # can use the raw Hs and Ht calls
             D_est = fstats.multilocus_D_est(Ht_est_list, Hs_est_list, n)
@@ -498,9 +499,9 @@ def calc_multilocus_f_statistics(Hs_est_dict, Ht_est_dict):
 
 
 def update_Hs_and_Ht_dicts(f_statistics, Hs_est_dict, Ht_est_dict):
-    
+
     for pop_pair in f_statistics.keys():
-    
+
         if Hs_est_dict.has_key(pop_pair) == True:
             Hs_est_dict[pop_pair].append(f_statistics[pop_pair]['Hs_est'])
         else:
@@ -510,25 +511,30 @@ def update_Hs_and_Ht_dicts(f_statistics, Hs_est_dict, Ht_est_dict):
             Ht_est_dict[pop_pair].append(f_statistics[pop_pair]['Ht_est'])
         else:
             Ht_est_dict[pop_pair] = [f_statistics[pop_pair]['Ht_est']]
-    
+
     return (Hs_est_dict, Ht_est_dict)
 
 def f_statistics_2_sorted_list(multilocus_f_statistics, order=[]):
-    
+
     if len(order) == 0:
-        
+
         for pair in multilocus_f_statistics.keys():
-            joined_pair = '.'.join(pair) 
+            joined_pair = '.'.join(pair)
             for stat in multilocus_f_statistics[pair].keys():
-                order.append('.'.join((joined_pair,stat)))
-        
+                order.append('.'.join((joined_pair, stat)))
+
         order.sort()
-    
+
+
     stats = []
     for key in order:
         pop1, pop2, stat = key.split(".")
-        stat = multilocus_f_statistics[(pop1,pop2)][stat]
-        stats.append(stat)
+
+        if multilocus_f_statistics[(pop1, pop2)] == None:                # TO DO: figure out why this occurs
+            stats.append(np.nan)
+        else:
+            value = multilocus_f_statistics[(pop1, pop2)][stat]
+            stats.append(value)
 
     return (stats, order)
 
@@ -546,6 +552,7 @@ def process_header(tabix_file):
 
     return chrm_lenghts_dict
 
+
 def generate_fstats_from_vcf_slices(slice_indicies, populations, header, args):
 
     for count, si in enumerate(slice_indicies):
@@ -582,6 +589,7 @@ def process_outgroup(vcf_line, populations):
     else:
         return None
 
+
 def identify_fixed_populations(allele_counts, order):
 
     if len(order) == 0:
@@ -603,7 +611,7 @@ def identify_fixed_populations(allele_counts, order):
 
 def vcf_line_to_snp_array(vcf_line_dict):
     pass
-    
+
 
 def calc_slice_stats(data):
     """Main function for caculating statistics.
@@ -615,7 +623,7 @@ def calc_slice_stats(data):
 
     #progress_meter(starting_time, chrm, stop, bp_processed, total_bp_in_dataset)
 
-    if len(tabix_slice) == 0:
+    if tabix_slice == None or len(tabix_slice) == 0:  # skip empty alignments
         return None
 
     else:
